@@ -62,12 +62,12 @@ impl Value for FontSet {
     fn read<T: Tape>(tape: &mut T) -> Result<Self> {
         let start = try!(tape.position());
 
-        let header = read_value!(tape, Header);
+        let header = try!(tape.take::<Header>());
         try!(tape.jump(start + header.header_size as u64));
-        let names = try!(read_value!(tape, Names).into());
-        let global_dictionaries = try!(read_value!(tape, Dictionaries).into());
-        let strings = read_value!(tape, Strings);
-        let global_subroutines = read_value!(tape, Subroutines);
+        let names = try!(try!(tape.take::<Names>()).into());
+        let global_dictionaries = try!(try!(tape.take::<Dictionaries>()).into());
+        let strings = try!(tape.take::<Strings>());
+        let global_subroutines = try!(tape.take::<Subroutines>());
 
         let mut encodings = vec![];
         let mut char_sets = vec![];
@@ -83,7 +83,7 @@ impl Value for FontSet {
 
             char_strings.push({
                 try!(tape.jump(start + get_single!(dictionary, CharStrings) as u64));
-                read_walue!(tape, get_single!(dictionary, CharStringType), CharStrings)
+                try!(tape.take_given::<CharStrings, _>(get_single!(dictionary, CharStringType)))
             });
 
             char_sets.push(match get_single!(dictionary, CharSet) {
@@ -92,22 +92,22 @@ impl Value for FontSet {
                 2 => CharSet::ExpertSubset,
                 offset => {
                     try!(tape.jump(start + offset as u64));
-                    read_walue!(tape, char_strings[i].len())
+                    try!(tape.take_given(char_strings[i].len()))
                 },
             });
 
             local_dictionaries.push({
                 let (size, offset) = get_double!(dictionary, Private);
                 try!(tape.jump(start + offset as u64));
-                let chunk: Vec<u8> = read_walue!(tape, size as usize);
-                read_value!(&mut Cursor::new(chunk), Operations)
+                let chunk = try!(tape.take_given::<Vec<u8>, _>(size as usize));
+                try!(Cursor::new(chunk).take::<Operations>())
             });
 
             local_subroutines.push({
                 let (_, mut offset) = get_double!(dictionary, Private);
                 offset += get_single!(&local_dictionaries[i], Subrs);
                 try!(tape.jump(start + offset as u64));
-                read_value!(tape)
+                try!(tape.take())
             });
         }
 
