@@ -1,5 +1,8 @@
 macro_rules! deref {
-    ($name:ident::$field:tt => $target:ty) => (itemize! {
+    (@itemize $($one:item)*) => ($($one)*);
+    ($name:ident::$field:tt => $target:ty) => (deref! {
+        @itemize
+
         impl ::std::ops::Deref for $name {
             type Target = $target;
 
@@ -16,7 +19,9 @@ macro_rules! deref {
             }
         }
     });
-    ($name:ident<$life:tt>::$field:tt => $target:ty) => (itemize! {
+    ($name:ident<$life:tt>::$field:tt => $target:ty) => (deref! {
+        @itemize
+
         impl<$life> ::std::ops::Deref for $name<$life> {
             type Target = $target;
 
@@ -35,46 +40,34 @@ macro_rules! deref {
     });
 }
 
-macro_rules! itemize(($($chunk:item)*) => ($($chunk)*));
-
 macro_rules! raise(
     ($message:expr) => (return Err(::Error::new(::std::io::ErrorKind::Other, $message)));
     ($($argument:tt)+) => (raise!(format!($($argument)+)));
 );
 
-macro_rules! read_value(
-    ($tape:expr) => (try!(::Value::read($tape)));
-    ($tape:expr, $kind:ty) => (try!(<$kind as ::Value>::read($tape)));
-);
-
-macro_rules! read_walue(
-    ($tape:expr, $parameter:expr) => (try!(::Walue::read($tape, $parameter)));
-    ($tape:expr, $parameter:expr, $kind:ty) => ({
-        try!(<$kind as ::Walue<_>>::read($tape, $parameter))
-    });
-);
-
+#[doc(hidden)]
+#[macro_export]
 macro_rules! table {
     ($(#[$attribute:meta])* pub $structure:ident {
-        $($field:ident ($kind:ty),)+
+        $($field:ident ($kind:ty),)*
     }) => (
-        table! { @define $(#[$attribute])* pub $structure { $($field ($kind),)+ } }
-        table! { @implement pub $structure { $($field,)+ } }
+        table! { @define $(#[$attribute])* pub $structure { $($field ($kind),)* } }
+        table! { @implement pub $structure { $($field,)* } }
     );
     (@define $(#[$attribute:meta])* pub $structure:ident {
-        $($field:ident ($kind:ty),)+
-    }) => (itemize! {
+        $($field:ident ($kind:ty),)*
+    }) => (
         $(#[$attribute])*
         #[derive(Clone, Debug, Eq, PartialEq)]
-        pub struct $structure { $(pub $field: $kind,)+ }
-    });
+        pub struct $structure { $(pub $field: $kind,)* }
+    );
     (@implement pub $structure:ident {
-        $($field:ident,)+
+        $($field:ident,)*
     }) => (
-        impl ::Value for $structure {
-            fn read<T: ::Tape>(tape: &mut T) -> ::Result<Self> {
+        impl $crate::Value for $structure {
+            fn read<T: $crate::Tape>(tape: &mut T) -> $crate::Result<Self> {
                 let mut table: $structure = unsafe { ::std::mem::uninitialized() };
-                $(::std::mem::forget(::std::mem::replace(&mut table.$field, read_value!(tape)));)+
+                $(::std::mem::forget(::std::mem::replace(&mut table.$field, try!(tape.take())));)+
                 Ok(table)
             }
         }
